strings.c
changeset 788 951b52443d48
parent 762 ef014856bd88
child 919 544f374ee392
--- a/strings.c	Thu Dec 23 18:14:12 2004 +0000
+++ b/strings.c	Thu Dec 23 18:28:13 2004 +0000
@@ -276,9 +276,9 @@
 	// convert from negative
 	if (number < 0) { *buff++ = '-'; number = -number; }
 
-	// add pre part
-	s = spec->pre;
-	while (s != spec->pre + lengthof(spec->pre) && (c=*s++)) *buff++ = c;
+	// add prefix part
+	s = spec->prefix;
+	while (s != spec->prefix + lengthof(spec->prefix) && (c=*s++)) *buff++ = c;
 
 	// for huge numbers, compact the number into k or M
 	if (compact) {
@@ -303,9 +303,9 @@
 
 	if (compact) *buff++ = compact;
 
-	// add post part
-	s = spec->post;
-	while (s != spec->post + lengthof(spec->post) && (c=*s++)) *buff++ = c;
+	// add suffix part
+	s = spec->suffix;
+	while (s != spec->suffix + lengthof(spec->suffix) && (c=*s++)) *buff++ = c;
 
 	return buff;
 }